// Copyright (c) 2018, project contributors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be found
// in the LICENSE file.

import 'dart:async';

import 'package:http_client/http_client.dart' as http;

import 'src/credentials.dart';
import 'src/request.dart';

export 'src/credentials.dart';

/// AWS S3 (Simple Storage Service).
class S3 {
  final Credentials _credentials;
  final http.Client _httpClient;

  /// AWS S3
  S3({Credentials credentials, http.Client httpClient})
      : _credentials = credentials,
        _httpClient = httpClient {
    assert(_credentials != null);
    assert(_httpClient != null);
  }

  S3Bucket bucket(String bucketName, {String region}) => new S3Bucket(
        credentials: _credentials,
        httpClient: _httpClient,
        bucketName: bucketName,
        region: region ?? 'us-east-1',
      );
}

/// AWS S3 Bucket
class S3Bucket {
  final Credentials _credentials;
  final http.Client _httpClient;
  final String _bucketName;
  final String _region;

  /// AWS S3 Bucket
  S3Bucket(
      {Credentials credentials,
      http.Client httpClient,
      String bucketName,
      String region})
      : _credentials = credentials,
        _httpClient = httpClient,
        _bucketName = bucketName,
        _region = region {
    assert(_credentials != null);
    assert(_httpClient != null);
    assert(_bucketName != null);
    assert(_region != null);
  }

  /// Whether the bucket exists.
  Future<bool> exists({bool checkAccess = false}) async {
    final response = await new AwsRequestBuilder(
      method: 'HEAD',
      uri: Uri.parse('https://$_bucketName.s3.$_region.amazonaws.com/'),
      credentials: _credentials,
      httpClient: _httpClient,
    ).sendRequest();
    print(response.statusCode);
    if (checkAccess) {
      return response.statusCode == 200;
    } else {
      return response.statusCode == 200 || response.statusCode == 403;
    }
  }
}
